@@ -14,7 +14,6 @@ import logging.config
 import logging.handlers
 import sys
 import traceback
-import weakref
 
 from daiquiri import output
 
@@ -58,9 +57,6 @@ class KeywordArgumentAdapter(logging.LoggerAdapter):
             self.logger.setLevel(level)
 
 
-_LOGGERS = weakref.WeakValueDictionary()
-
-
 def getLogger(name=None, **kwargs):
     """Build a logger with the given name.
 
@@ -68,17 +64,11 @@ def getLogger(name=None, **kwargs):
                  name, ``__name__``.
     :type name: string
     """
-    adapter = _LOGGERS.get(name)
-    if not adapter:
-        # NOTE(jd) Keep using the `adapter' variable here because so it's not
-        # collected by Python since _LOGGERS contains only a weakref
-        adapter = KeywordArgumentAdapter(logging.getLogger(name), kwargs)
-        _LOGGERS[name] = adapter
-    return adapter
+    return KeywordArgumentAdapter(logging.getLogger(name), kwargs)
 
 
 def setup(level=logging.WARNING, outputs=[output.STDERR], program_name=None,
-          capture_warnings=True):
+          capture_warnings=True, set_excepthook=True):
     """Setup Python logging.
 
     This will setup basic handlers for Python logging.
@@ -104,13 +94,14 @@ def setup(level=logging.WARNING, outputs=[output.STDERR], program_name=None,
 
     root_logger.setLevel(level)
 
-    program_logger = logging.getLogger(program_name)
+    if set_excepthook:
+        program_logger = logging.getLogger(program_name)
 
-    def logging_excepthook(exc_type, value, tb):
-        program_logger.critical(
-            "".join(traceback.format_exception(exc_type, value, tb)))
+        def logging_excepthook(exc_type, value, tb):
+            program_logger.critical(
+                "".join(traceback.format_exception(exc_type, value, tb)))
 
-    sys.excepthook = logging_excepthook
+        sys.excepthook = logging_excepthook
 
     if capture_warnings:
         logging.captureWarnings(True)
